@@ -50,9 +50,10 @@ LineEditData::LineEditData(QObject *parent, QLineEdit *target, int duration)
     This is needed because parents sometime disable the textChanged signal of the embedded
     QLineEdit
     */
-    if (qobject_cast<QSpinBox *>(_target.data()->parentWidget()) || qobject_cast<QDoubleSpinBox *>(_target.data()->parentWidget())) {
-        connect(_target.data()->parentWidget(), SIGNAL(valueChanged(QString)), SLOT(textChanged()));
-
+    if (auto spinbox = qobject_cast<QSpinBox *>(_target.data()->parentWidget())) {
+        connect(spinbox, &QSpinBox::textChanged, this, &LineEditData::textChanged);
+    } else if (auto spinbox = qobject_cast<QDoubleSpinBox *>(_target.data()->parentWidget())) {
+        connect(spinbox, &QDoubleSpinBox::textChanged, this, &LineEditData::textChanged);
     } else if (qobject_cast<QDateTimeEdit *>(_target.data()->parentWidget())) {
         connect(_target.data()->parentWidget(), SIGNAL(dateTimeChanged(QDateTime)), SLOT(textChanged()));
     }
